@@ -2,14 +2,20 @@
 """
 
 from sqlalchemy import inspect, orm
-from sqlalchemy.ext.declarative import declarative_base, DeclarativeMeta
+from sqlalchemy.ext.declarative import (
+    declarative_base,
+    DeclarativeMeta,
+    declared_attr
+)
 
 from . import query, events
 from .utils import (
     is_sequence,
     has_primary_key,
     camelcase_to_underscore,
-    get_mapper_class
+    get_mapper_class,
+    merge_declarative_args,
+    unique
 )
 from ._compat import iteritems
 
@@ -107,14 +113,38 @@ class ModelBase(object):
             See :func:`make_declarative_base` for automatic implementation.
     """
 
-    __table_args__ = {}
-    __mapper_args__ = {}
     __bind_key__ = None
     __events__ = {}
-
     query_class = query.QueryModel
     query = None
 
+    @declared_attr
+    def __table_args__(cls):  # pylint: disable=no-self-argument
+        # pylint: disable=no-member
+        args, kargs = merge_declarative_args(cls.__bases__, '__table_args__')
+        local_args, local_kargs = merge_declarative_args(
+            [cls], '__local_table_args__')
+
+        args = unique(args + local_args)
+        kargs.update(local_kargs)
+
+        # Append kargs onto end of args to adhere to SQLAlchemy requirements.
+        args.append(kargs)
+
+        return tuple(args)
+
+    @declared_attr
+    def __mapper_args__(cls):  # pylint: disable=no-self-argument
+        # pylint: disable=no-member
+        # NOTE: Mapper args are only allowed to be a dict so we ignore `args`.
+        _, kargs = merge_declarative_args(cls.__bases__, '__mapper_args__')
+        _, local_kargs = merge_declarative_args([cls],
+                                                '__local_mapper_args__')
+
+        kargs.update(local_kargs)
+
+        return kargs
+
     def __init__(self, *args, **kargs):
         """Initialize model instance by calling :meth:`update`."""
         self.update(*args, **kargs)
@@ -137,10 +167,8 @@ class ModelBase(object):
 
         data = data_dict if isinstance(data_dict, dict) else kargs
 
-        update_fields = data.keys()
-
         for field, value in iteritems(data):
-            if hasattr(self, field) and field in update_fields:
+            if hasattr(self, field):
                 self._set_field(field, value)
 
     def _set_field(self, field, value):
@@ -172,7 +200,6 @@ class ModelBase(object):
 
         if is_sequence_relationship and is_sequence(value):
             # Convert each value instance to relationship class.
-            relationship_class = get_mapper_class(self.__class__, field)
             value = [relationship_class(val) if isinstance(val, dict)
                      else val
                      for val in value]
@@ -348,6 +375,7 @@ class ModelBase(object):
     @classmethod
     def descriptors(cls):
         """Return all ORM descriptors"""
+        # pylint: disable=maybe-no-member
         return [descr for descr in inspect(cls).all_orm_descriptors.keys()
                 if not descr.startswith('__')]
 
